@@ -11,6 +11,8 @@ import json
 import os
 import shutil
 
+from typing import Dict, List, Optional, Union
+
 from histore.archive.base import PersistentArchive
 from histore.archive.manager.base import ArchiveManager
 from histore.archive.manager.descriptor import ArchiveDescriptor
@@ -19,11 +21,13 @@ import histore.config as config
 import histore.util as util
 
 
-class PersistentArchiveManager(ArchiveManager):
+class FileSystemArchiveManager(ArchiveManager):
     """The persistent archive manager maintains a set of archives on disk. The
     list of archive descriptors is also maintained on disk as a Json file.
     """
-    def __init__(self, basedir=None, exists=False):
+    def __init__(
+        self, basedir: Optional[str] = None, create: Optional[bool] = False
+    ):
         """Initialize the base directory under which all archives are stored in
         individual sub-folders. If the base directory is not given the value
         will be read from the environment variable HISTORE_BASEDIR or the
@@ -35,35 +39,30 @@ class PersistentArchiveManager(ArchiveManager):
         ----------
         basedir: string
             Path to dorectory on disk where archives are maintained.
-        exists: bool, default=False
-            Raise an error if the given base directory is not empty or contains
-            the descriptor file.
+        create: bool, default=False
+            Create a fresh instance of the archive manager if True. This will
+            delete all files in the base directory.
         """
         if basedir is None:
             basedir = config.BASEDIR()
+        self.basedir = basedir
         # Initialize path to file that maintains archive descriptors.
-        self.descriptorfile = os.path.join(basedir, 'archives.json')
-        exists_descriptorfile = os.path.isfile(self.descriptorfile)
-        # Raise error if the archive manager base directory is expected to
-        # exist.
-        if exists:
-            # Raise error if (i) the directory does not exists, or (ii) exists
-            # but does not contain the descriptor file.
-            if not os.path.isdir(basedir):
-                raise ValueError('archive manager does not exist')
-            elif os.listdir(basedir) and not exists_descriptorfile:
-                raise ValueError('archive manager does not exist')
-        self.basedir = util.createdir(basedir)
+        if create:
+            # Clear all files in the base directory if it exists.
+            if os.path.isdir(self.basedir):
+                util.cleardir(self.basedir)
+        util.createdir(self.basedir)
         # Initialize the internal cache of archive descriptors
+        self.descriptorfile = os.path.join(basedir, 'archives.json')
         self._archives = dict()
-        if exists_descriptorfile:
+        if os.path.isfile(self.descriptorfile):
             with open(self.descriptorfile, 'r') as f:
                 doc = json.load(f)
             for obj in doc:
                 descriptor = ArchiveDescriptor(obj)
                 self._archives[descriptor.identifier()] = descriptor
 
-    def archives(self):
+    def archives(self) -> Dict[str, ArchiveDescriptor]:
         """Get dictionary of archive descriptors. The returned dictionary maps
         archive identifier to their descriptor.
 
@@ -74,9 +73,10 @@ class PersistentArchiveManager(ArchiveManager):
         return self._archives
 
     def create(
-        self, name=None, description=None, primary_key=None, encoder=None,
-        decoder=None
-    ):
+        self, name: Optional[str] = None, description: Optional[str] = None,
+        primary_key: Optional[Union[List[str], str]] = None,
+        encoder: Optional[str] = None, decoder: Optional[str] = None
+    ) -> ArchiveDescriptor:
         """Create a new archive object. Raises a ValueError if an archive with
         the given name exists.
 
@@ -121,7 +121,7 @@ class PersistentArchiveManager(ArchiveManager):
         self.write()
         return descriptor
 
-    def delete(self, identifier):
+    def delete(self, identifier: str):
         """Delete the archive with the given identifier.
 
         Parameters
@@ -136,7 +136,7 @@ class PersistentArchiveManager(ArchiveManager):
             del self._archives[identifier]
             self.write()
 
-    def get(self, identifier):
+    def get(self, identifier: str) -> PersistentArchive:
         """Get the archive that is associated with the given identifier. Raises
         a ValueError if the identifier is unknown.
 
@@ -176,7 +176,7 @@ class PersistentArchiveManager(ArchiveManager):
             decoder=decoder
         )
 
-    def rename(self, identifier, name):
+    def rename(self, identifier: str, name: str):
         """Rename the specified archive. Raises a ValueError if the identifier
         is unknown or if an archive with the given name exist.
 
